@@ -1,3 +1,3 @@
-require 'backports/tools'
+require 'backports/tools/make_block_optional'
 
 Backports.make_block_optional Struct, :each, :test_on => Struct.new(:foo, :bar).new
