@@ -1,7 +1,8 @@
 begin
   File.open(__FILE__, :mode => 'r'){}
 rescue TypeError
-  require 'backports/tools'
+  require 'backports/tools/alias_method_chain'
+  require 'backports/tools/io'
 
   def open_with_options_hash(file, mode = nil, perm_or_options = Backports::Undefined)
     mode, perm = Backports.combine_mode_perm_and_option(mode, perm_or_options)
@@ -19,7 +20,7 @@ rescue TypeError
 end
 
 if RUBY_VERSION < '1.9'
-  require 'backports/tools'
+  require 'backports/tools/path'
 
   Backports.convert_first_argument_to_path File, :open
 end
