@@ -11,7 +11,10 @@
 # Original Documentation:: Gavin Sinclair (sourced from <i>Ruby in a Nutshell</i> (Matsumoto, O'Reilly))
 ##
 
+begin
 require "e2mmap.rb"
+rescue LoadError
+else
 
 module ExceptionForMatrix # :nodoc:
   def_e2message(TypeError, "wrong argument type %s (expected %s)")
@@ -117,7 +120,8 @@ end
 # * #to_s
 # * #inspect
 #
-Backports.suppress_verbose_warnings do
+require 'backports/tools/suppress_verbose_warnings' # *** Backports addition
+Backports.suppress_verbose_warnings do # *** Backports addition
 class Matrix
   include Enumerable
   include ExceptionForMatrix
@@ -970,7 +974,7 @@ class Matrix
   #     => 67 96
   #        48 99
   #
-  def ** (other)
+  def **(other)
     case other
     when Integer
       x = self
@@ -1465,7 +1469,7 @@ end
       end
     end
 
-    def / (other)
+    def /(other)
       case other
       when Numeric
         Scalar.new(@value / other)
@@ -1478,7 +1482,7 @@ end
       end
     end
 
-    def ** (other)
+    def **(other)
       case other
       when Numeric
         Scalar.new(@value ** other)
@@ -1869,3 +1873,5 @@ class Vector
   end
 end
 end
+
+end
